@@ -16,7 +16,7 @@ test_batch <- function(abess_fit, dataset, family) {
   
   ## estimation
   # oracle estimation by glm function:
-  dat <- cbind.data.frame("y" = dataset[["y"]], 
+  dat <- cbind.data.frame("y" = dataset[["y"]],
                           dataset[["x"]][, true_index])
   
   oracle_est <- glm(y ~ ., data = dat, family = family)
@@ -42,7 +42,7 @@ test_batch <- function(abess_fit, dataset, family) {
   ## deviance
   f <- family()
   if (f[["family"]] == "gaussian") {
-    oracle_dev <- mean((oracle_est[["residuals"]])^2)
+    oracle_dev <- mean((oracle_est[["residuals"]]) ^ 2)
   } else if (f[["family"]] != "poisson") {
     oracle_dev <- deviance(oracle_est) / 2
   } else {
@@ -51,113 +51,158 @@ test_batch <- function(abess_fit, dataset, family) {
   expect_equal(oracle_dev, extract(abess_fit)[["dev"]])
 }
 
-test_batch_multivariate <- function(abess_fit, dataset, gaussian = TRUE) {
-  true_index <- which(apply(dataset[["beta"]], 1, function(x) {
-    all(x != 0)
-  }))
-  support_size <- length(true_index)
-  
-  ## support size
-  fit_s_size <- abess_fit[["best.size"]]
-  expect_equal(fit_s_size, support_size)
-  
-  ## subset
-  coef_value <- coef(abess_fit, support.size = fit_s_size)[[1]]
-  est_index <- unique(coef_value@i)[-1]
-  expect_equal(est_index, true_index)
-  
-  ## estimation ##
-  
-  # estimation by abess:
-  est_beta <- as.matrix(coef_value[1 + est_index, ])
-  est_coef0 <- coef_value[1, , drop = TRUE]
-  names(est_beta) <- NULL
-  names(est_coef0) <- NULL
-  
-  if (gaussian) {
-    # oracle estimation by lm function:
-    dat <- cbind.data.frame(dataset[["y"]], 
-                            dataset[["x"]][, true_index])
+test_batch_multivariate <-
+  function(abess_fit, dataset, gaussian = TRUE) {
+    true_index <- which(apply(dataset[["beta"]], 1, function(x) {
+      all(x != 0)
+    }))
+    support_size <- length(true_index)
     
-    oracle_est <- lm(cbind(y1, y2, y3) ~ ., data = dat)
-    oracle_est <- as.matrix(coef(oracle_est))
-    oracle_beta <- oracle_est[-1, ]
-    oracle_coef0 <- oracle_est[1, , drop = TRUE]
-    names(oracle_beta) <- NULL
-    names(oracle_coef0) <- NULL
-
+    ## support size
+    fit_s_size <- abess_fit[["best.size"]]
+    expect_equal(fit_s_size, support_size)
     
-    expect_equal(oracle_beta, est_beta, tolerance = 1e-5)
-    expect_equal(oracle_coef0, est_coef0, tolerance = 1e-5)
-  } else {
-    require(nnet)
-    # oracle estimation by nnet function:
-    dat <- cbind.data.frame("y" = 2 - dataset[["y"]], 
-                            dataset[["x"]][, true_index])
-    set.seed(1); 
-    suppressMessages(multinom_model <- multinom(y ~ ., data = dat, maxit = 15, trace = FALSE))
-    oracle_est <- as.matrix(coef(multinom_model))
-    oracle_est <- t(oracle_est[2:1, ])
-    oracle_beta <- oracle_est[-1, ]
-    oracle_coef0 <- oracle_est[1, , drop = TRUE]
+    ## subset
+    coef_value <- coef(abess_fit, support.size = fit_s_size)[[1]]
+    est_index <- unique(coef_value@i)[-1]
+    expect_equal(est_index, true_index)
     
-    expect_lt(mean(oracle_beta - est_beta[, 1:2]), 0.1)
-    expect_lt(mean(oracle_coef0 - est_coef0[1:2]), 1)
+    ## estimation ##
+    
+    # estimation by abess:
+    est_beta <- as.matrix(coef_value[1 + est_index, ])
+    est_coef0 <- coef_value[1, , drop = TRUE]
+    names(est_beta) <- NULL
+    names(est_coef0) <- NULL
+    
+    if (gaussian) {
+      # oracle estimation by lm function:
+      dat <- cbind.data.frame(dataset[["y"]],
+                              dataset[["x"]][, true_index])
+      
+      oracle_est <- lm(cbind(y1, y2, y3) ~ ., data = dat)
+      oracle_est <- as.matrix(coef(oracle_est))
+      oracle_beta <- oracle_est[-1, ]
+      oracle_coef0 <- oracle_est[1, , drop = TRUE]
+      names(oracle_beta) <- NULL
+      names(oracle_coef0) <- NULL
+      
+      
+      expect_equal(oracle_beta, est_beta, tolerance = 1e-5)
+      expect_equal(oracle_coef0, est_coef0, tolerance = 1e-5)
+    } else {
+      require(nnet)
+      # oracle estimation by nnet function:
+      dat <- cbind.data.frame("y" = 2 - dataset[["y"]],
+                              dataset[["x"]][, true_index])
+      set.seed(1)
+      suppressMessages(multinom_model <-
+                         multinom(
+                           y ~ .,
+                           data = dat,
+                           maxit = 15,
+                           trace = FALSE
+                         ))
+      oracle_est <- as.matrix(coef(multinom_model))
+      oracle_est <- t(oracle_est[2:1, ])
+      oracle_beta <- oracle_est[-1, ]
+      oracle_coef0 <- oracle_est[1, , drop = TRUE]
+      
+      expect_lt(mean(oracle_beta - est_beta[, 1:2]), 0.1)
+      expect_lt(mean(oracle_coef0 - est_coef0[1:2]), 1)
+    }
+    
+    ## deviance
+    # f <- family()
+    # if (f[["family"]] == "gaussian") {
+    #   oracle_dev <- mean((oracle_est[["residuals"]])^2)
+    # } else {
+    #   oracle_dev <- deviance(oracle_est) / 2
+    # }
+    # expect_equal(oracle_dev, abess_fit[["dev"]][fit_s_size + 1])
   }
-  
-  ## deviance
-  # f <- family()
-  # if (f[["family"]] == "gaussian") {
-  #   oracle_dev <- mean((oracle_est[["residuals"]])^2)
-  # } else {
-  #   oracle_dev <- deviance(oracle_est) / 2
-  # }
-  # expect_equal(oracle_dev, abess_fit[["dev"]][fit_s_size + 1])
-}
 
 test_that("Covariance update works", {
-  skip('Skip Covariance update!')
-  n <- 1000
+  ## n > p case:
+  n <- 100
+  p <- 20
+  support_size <- 3
+  
+  dataset <- generate.data(n, p, support_size, seed = 1)
+  t1 <- system.time(abess_fit1 <- abess(
+    dataset[["x"]],
+    dataset[["y"]],
+    cov.update = FALSE,
+    num.threads = 1
+  ))
+  t2 <- system.time(abess_fit2 <- abess(dataset[["x"]],
+                                        dataset[["y"]],
+                                        num.threads = 1))
+  
+  abess_fit1[["call"]] <- NULL
+  abess_fit2[["call"]] <- NULL
+  expect_true(all.equal(abess_fit1, abess_fit2))
+  # expect_lt(t2[3], t1[3])
+  
+  ## p > n case:
+  n <- 50
+  p <- 100
+  support_size <- 3
+  
+  dataset <- generate.data(n, p, support_size, seed = 1)
+  t1 <- system.time(abess_fit1 <- abess(
+    dataset[["x"]],
+    dataset[["y"]],
+    cov.update = FALSE,
+    num.threads = 1
+  ))
+  t2 <- system.time(abess_fit2 <- abess(dataset[["x"]],
+                                        dataset[["y"]],
+                                        num.threads = 1))
+  
+  abess_fit1[["call"]] <- NULL
+  abess_fit2[["call"]] <- NULL
+  expect_true(all.equal(abess_fit1, abess_fit2))
+})
+
+test_that("OPENMP works", {
+  skip("Skip OPENMP!")
+  skip_on_os("mac")
+  
+  if (!require("ps")) {
+    install.packages("ps")
+  }
+  num_threads <- ps_num_threads()
+  print(num_threads)
+  skip_if(num_threads == 1)
+  
+  n <- 500
   p <- 500
   support_size <- 3
   
   dataset <- generate.data(n, p, support_size, seed = 1)
-  t1 <- system.time(abess_fit1 <- abess(dataset[["x"]], 
-                                        dataset[["y"]],
-                                        cov.update = FALSE, 
-                                        num.threads = 1))
-  t2 <- system.time(abess_fit2 <- abess(dataset[["x"]], 
-                                        dataset[["y"]], 
-                                        num.threads = 1))
+  t1 <- system.time(abess_fit1 <- abess(
+    dataset[["x"]],
+    dataset[["y"]],
+    tune.type = "cv",
+    num.threads = 1
+  ))
+  t2 <- system.time(abess_fit2 <- abess(
+    dataset[["x"]],
+    dataset[["y"]],
+    tune.type = "cv",
+    num.threads = 5
+  ))
   
   expect_lt(t2[3], t1[3])
   abess_fit1[["call"]] <- NULL
   abess_fit2[["call"]] <- NULL
   expect_true(all.equal(abess_fit1, abess_fit2))
-  
-  
-  # n <- 100
-  # p <- 5000
-  # support_size <- 3
-  # 
-  # dataset <- generate.data(n, p, support_size, seed = 1)
-  # t1 <- system.time(abess_fit1 <- abess(dataset[["x"]], 
-  #                                       dataset[["y"]],
-  #                                       cov.update = FALSE, 
-  #                                       num.threads = 1))
-  # t2 <- system.time(abess_fit2 <- abess(dataset[["x"]], 
-  #                                       dataset[["y"]], 
-  #                                       num.threads = 1))
-  # 
-  # expect_gt(t2[3], t1[3])
-  # abess_fit1[["call"]] <- NULL
-  # abess_fit2[["call"]] <- NULL
-  # expect_true(all.equal(abess_fit1, abess_fit2))
 })
 
 test_that("abess (gaussian) works", {
-  n <- 300
-  p <- 300
+  n <- 100
+  p <- 50
   support_size <- 3
   
   ## default interface
@@ -166,7 +211,8 @@ test_that("abess (gaussian) works", {
   test_batch(abess_fit, dataset, gaussian)
   
   ## formula interface
-  dat <- cbind.data.frame(dataset[["x"]][, 1:30], "y" = dataset[["y"]], 
+  dat <- cbind.data.frame(dataset[["x"]][, 1:30],
+                          "y" = dataset[["y"]],
                           dataset[["x"]][, 31:p])
   abess_fit <- abess(y ~ ., data = dat)
   test_batch(abess_fit, dataset, gaussian)
@@ -177,16 +223,26 @@ test_that("abess (binomial) works", {
   p <- 100
   support.size <- 3
   
-  dataset <- generate.data(n, p, support.size, 
+  dataset <- generate.data(n, p, support.size,
                            family = "binomial", seed = 1)
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], 
-                     family = "binomial", tune.type = "cv", 
-                     newton = "exact", newton.thresh = 1e-8)
+  abess_fit <- abess(
+    dataset[["x"]],
+    dataset[["y"]],
+    family = "binomial",
+    tune.type = "cv",
+    newton = "exact",
+    newton.thresh = 1e-8
+  )
   test_batch(abess_fit, dataset, binomial)
   
-  abess_fit1 <- abess(dataset[["x"]], dataset[["y"]], 
-                      family = "binomial", tune.type = "cv", 
-                      newton = "approx", newton.thresh = 1e-8)
+  abess_fit1 <- abess(
+    dataset[["x"]],
+    dataset[["y"]],
+    family = "binomial",
+    tune.type = "cv",
+    newton = "approx",
+    newton.thresh = 1e-8
+  )
   beta <- extract(abess_fit)[["support.beta"]]
   beta1 <- extract(abess_fit1)[["support.beta"]]
   expect_true(all(abs(beta - beta1) < 1e-3))
@@ -196,14 +252,19 @@ test_that("abess (cox) works", {
   if (!require("survival")) {
     install.packages("survival")
   }
-  n <- 100
-  p <- 50
+  n <- 60
+  p <- 20
   support.size <- 3
   
-  dataset <- generate.data(n, p, support.size, 
+  dataset <- generate.data(n, p, support.size,
                            family = "cox", seed = 1)
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], 
-                     family = "cox", newton = "approx", tune.type = "cv")
+  abess_fit <- abess(
+    dataset[["x"]],
+    dataset[["y"]],
+    family = "cox",
+    newton = "approx",
+    tune.type = "cv"
+  )
   
   ## support size
   fit_s_size <- abess_fit[["best.size"]]
@@ -219,8 +280,10 @@ test_that("abess (cox) works", {
   # true value:
   true_beta <- dataset[["beta"]][true_index]
   # estimated by coxph:
-  dat <- cbind.data.frame(dataset[["y"]], dataset[["x"]][, true_index])
-  oracle_est <- survival::coxph(survival::Surv(time, status) ~ ., data = dat)
+  dat <-
+    cbind.data.frame(dataset[["y"]], dataset[["x"]][, true_index])
+  oracle_est <-
+    survival::coxph(survival::Surv(time, status) ~ ., data = dat)
   oracle_beta <- coef(oracle_est)
   # estimated by abess:
   est_beta <- coef_value@x
@@ -233,24 +296,33 @@ test_that("abess (cox) works", {
   }
   
   ## Surv object input:
-  dataset[["y"]] <- survival::Surv(time = dataset[["y"]][, 1], 
+  dataset[["y"]] <- survival::Surv(time = dataset[["y"]][, 1],
                                    event = dataset[["y"]][, 2])
-  abess_fit1 <- abess(dataset[["x"]], dataset[["y"]], 
-                      family = "cox", newton = "approx", 
-                      tune.type = "cv")
+  abess_fit1 <- abess(
+    dataset[["x"]],
+    dataset[["y"]],
+    family = "cox",
+    newton = "approx",
+    tune.type = "cv"
+  )
   expect_true(all.equal(abess_fit, abess_fit1))
 })
 
 test_that("abess (poisson) works", {
+  skip("poisson")
   n <- 200
   p <- 100
   support.size <- 3
   
-  dataset <- generate.data(n, p, support.size, 
+  dataset <- generate.data(n, p, support.size,
                            family = "poisson", seed = 1)
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], 
-                     family = "poisson", tune.type = "cv", 
-                     newton.thresh = 1e-8)
+  abess_fit <- abess(
+    dataset[["x"]],
+    dataset[["y"]],
+    family = "poisson",
+    tune.type = "cv",
+    newton.thresh = 1e-8
+  )
   test_batch(abess_fit, dataset, poisson)
 })
 
@@ -260,14 +332,21 @@ test_that("abess (mgaussian) works", {
   support_size <- 3
   
   ## default interface
-  dataset <- generate.data(n, p, support_size, seed = 1, family = "mgaussian")
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], 
+  dataset <-
+    generate.data(n, p, support_size, seed = 1, family = "mgaussian")
+  abess_fit <- abess(dataset[["x"]], dataset[["y"]],
                      family = "mgaussian", tune.type = "cv")
   test_batch_multivariate(abess_fit, dataset)
   
   ## formula interface
   dat <- cbind.data.frame(dataset[["x"]], dataset[["y"]])
-  abess_fit <- abess(cbind(y1, y2, y3) ~ ., data = dat, family = "mgaussian", tune.type = "cv")
+  abess_fit <-
+    abess(
+      cbind(y1, y2, y3) ~ .,
+      data = dat,
+      family = "mgaussian",
+      tune.type = "cv"
+    )
   test_batch_multivariate(abess_fit, dataset)
 })
 
@@ -277,20 +356,25 @@ test_that("abess (multinomial) works", {
   n <- 600
   p <- 100
   support_size <- 3
-  dataset <- generate.data(n, p, support_size, 
+  dataset <- generate.data(n, p, support_size,
                            seed = 1, family = "multinomial")
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], 
-                     family = "multinomial", tune.type = "cv", 
-                     newton = "approx")
+  abess_fit <- abess(
+    dataset[["x"]],
+    dataset[["y"]],
+    family = "multinomial",
+    tune.type = "cv",
+    newton = "approx"
+  )
   test_batch_multivariate(abess_fit, dataset, FALSE)
-
+  
   ## not pass:
   n <- 200
   p <- 500
   support_size <- 3
   
-  dataset <- generate.data(n, p, support_size, seed = 1, family = "multinomial")
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], 
+  dataset <-
+    generate.data(n, p, support_size, seed = 1, family = "multinomial")
+  abess_fit <- abess(dataset[["x"]], dataset[["y"]],
                      family = "multinomial", tune.type = "cv")
   test_batch_multivariate(abess_fit, dataset, FALSE)
 })
@@ -305,34 +389,47 @@ test_that("Fast than Lasso (gaussian) works", {
   support_size <- 3
   
   dataset <- generate.data(n, p, support_size, seed = 1)
-  t1 <- system.time(abess_fit <- abess(dataset[["x"]], dataset[["y"]], 
-                                       tune.type = "cv", nfolds = 10, num.threads = 8))
+  t1 <-
+    system.time(abess_fit <- abess(
+      dataset[["x"]],
+      dataset[["y"]],
+      tune.type = "cv",
+      nfolds = 10,
+      num.threads = 8
+    ))
   tune_num <- length(abess_fit[["support.size"]])
-  glmnet_fit <- glmnet::glmnet(dataset[["x"]], dataset[["y"]], nlambda = tune_num)
-  t2 <- system.time(glmnet_fit <- glmnet::cv.glmnet(dataset[["x"]], dataset[["y"]], 
-                                                    lambda = glmnet_fit[["lambda"]], nfolds = 10))
+  glmnet_fit <-
+    glmnet::glmnet(dataset[["x"]], dataset[["y"]], nlambda = tune_num)
+  t2 <-
+    system.time(
+      glmnet_fit <- glmnet::cv.glmnet(dataset[["x"]], dataset[["y"]],
+                                      lambda = glmnet_fit[["lambda"]], nfolds = 10)
+    )
   expect_lt(t1[3], t2[3])
 })
 
 test_that("abess (golden section) works", {
-  n <- 200
-  p <- 200
+  n <- 100
+  p <- 50
   support_size <- 3
   dataset <- generate.data(n, p, support_size)
   
   ## default search range
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], tune.path = "gsection")
+  abess_fit <-
+    abess(dataset[["x"]], dataset[["y"]], tune.path = "gsection")
   test_batch(abess_fit, dataset, gaussian)
   
   ## self-defined search range
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], 
-                     tune.path = "gsection", gs.range = c(1, 6))
+  abess_fit <- abess(dataset[["x"]],
+                     dataset[["y"]],
+                     tune.path = "gsection",
+                     gs.range = c(1, 6))
   test_batch(abess_fit, dataset, gaussian)
 })
 
 test_that("abess (output) works", {
-  n <- 50
-  p <- 50
+  n <- 30
+  p <- 30
   support_size <- 3
   
   dataset <- generate.data(n, p, support_size, seed = 1)
@@ -345,11 +442,12 @@ test_that("abess (output) works", {
 })
 
 test_that("abess (always-include) works", {
-  n <- 100
+  n <- 50
   p <- 20
   support_size <- 3
   dataset <- generate.data(n, p, support_size)
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], always.include = c(1))
+  abess_fit <-
+    abess(dataset[["x"]], dataset[["y"]], always.include = c(1))
   expect_true(all((abess_fit[["beta"]][1, , drop = TRUE][-1] != 0)))
 })
 
@@ -361,4 +459,11 @@ test_that("abess (L2 regularization) works", {
   abess_fit <- abess(dataset[["x"]], dataset[["y"]], lambda = 0.1)
   expect_true(all(diff(abess_fit[["edf"]]) > 0))
   expect_true(all(abess_fit[["edf"]] <= abess_fit[["support.size"]]))
+  
+  n <- 20
+  p <- 100
+  dataset <- generate.data(n, p, support_size)
+  abess_fit2 <- abess(dataset[["x"]], dataset[["y"]])
+  expect_gt(extract(abess_fit)[["support.size"]],
+            extract(abess_fit2)[["support.size"]])
 })
