@@ -2,8 +2,8 @@ library(abess)
 library(testthat)
 
 test_that("generic (univariate) works", {
-  n <- 100
-  p <- 100
+  n <- 60
+  p <- 60
   support_size <- 3
   
   dataset <- generate.data(n, p, support_size, seed = 1)
@@ -20,8 +20,8 @@ test_that("generic (univariate) works", {
   expect_visible(coef(abess_fit, support.size = 2))
   expect_visible(coef(abess_fit, sparse = FALSE))
   
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ]))
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ], support.size = c(3, 4)))
+  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10,]))
+  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10,], support.size = c(3, 4)))
   
   expect_visible(extract(abess_fit))
   expect_visible(extract(abess_fit, support.size = 4))
@@ -32,38 +32,43 @@ test_that("generic (univariate) works", {
   expect_visible(deviance(abess_fit, type = "bic"))
   expect_visible(deviance(abess_fit, type = "ebic"))
   
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], tune.type = "gic")
+  abess_fit <-
+    abess(dataset[["x"]], dataset[["y"]], tune.type = "gic")
   expect_visible(deviance(abess_fit, type = "gic"))
   
   ## binomial
-  dataset <- generate.data(n, p, support_size, seed = 1, family = "binomial")
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], family = "binomial")
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ]))
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ], type = "response"))
+  dataset <-
+    generate.data(n, p, support_size, seed = 1, family = "binomial")
+  abess_fit <-
+    abess(dataset[["x"]], dataset[["y"]], family = "binomial")
+  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10,]))
+  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10,], type = "response"))
   
   ## poisson
-  dataset <- generate.data(n, p, support_size, seed = 1, family = "poisson")
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], family = "poisson")
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ]))
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ], type = "response"))
+  dataset <-
+    generate.data(n, p, support_size, seed = 1, family = "poisson")
+  abess_fit <-
+    abess(dataset[["x"]], dataset[["y"]], family = "poisson")
+  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10,]))
+  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10,], type = "response"))
   
   ## cox
-  dataset <- generate.data(n, p, support_size, seed = 1, family = "cox")
+  dataset <-
+    generate.data(n, p, support_size, seed = 1, family = "cox")
   abess_fit <- abess(dataset[["x"]], dataset[["y"]], family = "cox")
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ]))
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ], type = "response"))
+  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10,]))
+  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10,], type = "response"))
 })
 
 
 test_that("generic (multivariate) works", {
-  skip_on_os("mac")
-  skip_on_os("solaris")
-  n <- 100
-  p <- 100
+  n <- 60
+  p <- 60
   support_size <- 3
   
-  dataset <- generate.data(n, p, support_size, seed = 1, family = "mgaussian")
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], 
+  dataset <-
+    generate.data(n, p, support_size, seed = 1, family = "mgaussian")
+  abess_fit <- abess(dataset[["x"]], dataset[["y"]],
                      family = "mgaussian", tune.type = "gic")
   
   expect_invisible(print(abess_fit))
@@ -77,8 +82,9 @@ test_that("generic (multivariate) works", {
   expect_visible(coef(abess_fit, support.size = 2))
   expect_visible(coef(abess_fit, sparse = FALSE))
   
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ]))
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ], 
+  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10,]))
+  expect_visible(predict(abess_fit,
+                         newx = dataset[["x"]][1:10,],
                          support.size = c(3, 4)))
   
   expect_visible(extract(abess_fit))
@@ -91,16 +97,18 @@ test_that("generic (multivariate) works", {
   expect_visible(deviance(abess_fit, type = "ebic"))
   
   ## multinomial
-  dataset <- generate.data(n, p, support_size, seed = 1, family = "multinomial")
-  abess_fit <- abess(dataset[["x"]], dataset[["y"]], family = "multinomial")
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ]))
-  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10, ], type = "response"))
+  dataset <-
+    generate.data(n, p, support_size, seed = 1, family = "multinomial")
+  abess_fit <-
+    abess(dataset[["x"]], dataset[["y"]], family = "multinomial")
+  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10,]))
+  expect_visible(predict(abess_fit, newx = dataset[["x"]][1:10,], type = "response"))
 })
 
 
 test_that("generic (abesspca) works", {
-  n <- 100
-  p <- 100
+  n <- 60
+  p <- 60
   support_size <- 3
   
   ## F-PCA
@@ -117,7 +125,8 @@ test_that("generic (abesspca) works", {
   expect_visible(coef(abess_fit, sparse = FALSE))
   
   ## K-PCA
-  abess_fit <- abesspca(dataset[["x"]], sparse.type = "kpc", 
+  abess_fit <- abesspca(dataset[["x"]],
+                        sparse.type = "kpc",
                         support.size = c(1, 1, 1))
   
   expect_invisible(print(abess_fit))
@@ -138,19 +147,53 @@ test_that("data generator works", {
   
   expect_visible(generate.data(n, p, support_size, seed = 1, cortype = 2))
   expect_visible(generate.data(n, p, support_size, seed = 1, cortype = 3))
-
-  expect_visible(generate.data(n, p, seed = 1, family = "gaussian", 
-                               beta = c(rep(1, 5), rep(0, p - 5))))
-  expect_visible(generate.data(n, p, seed = 1, family = "binomial", 
-                               beta = c(rep(1, 5), rep(0, p - 5))))
-  expect_visible(generate.data(n, p, seed = 1, family = "poisson", 
-                               beta = c(rep(1, 5), rep(0, p - 5))))
-  expect_visible(generate.data(n, p, seed = 1, family = "cox", 
-                               beta = c(rep(1, 5), rep(0, p - 5))))
-  expect_visible(generate.data(n, p, seed = 1, family = "mgaussian", 
-                               beta = matrix(rep(c(rep(1, 5), rep(0, p - 5)), 3), 
-                                             ncol = 3)))
-  expect_visible(generate.data(n, p, seed = 1, family = "multinomial", 
-                               beta = matrix(rep(c(rep(1, 5), rep(0, p - 5)), 3), 
-                                             ncol = 3)))
+  
+  expect_visible(generate.data(
+    n,
+    p,
+    seed = 1,
+    family = "gaussian",
+    beta = c(rep(1, 5), rep(0, p - 5))
+  ))
+  expect_visible(generate.data(
+    n,
+    p,
+    seed = 1,
+    family = "binomial",
+    beta = c(rep(1, 5), rep(0, p - 5))
+  ))
+  expect_visible(generate.data(
+    n,
+    p,
+    seed = 1,
+    family = "poisson",
+    beta = c(rep(1, 5), rep(0, p - 5))
+  ))
+  expect_visible(generate.data(
+    n,
+    p,
+    seed = 1,
+    family = "cox",
+    beta = c(rep(1, 5), rep(0, p - 5))
+  ))
+  expect_visible(generate.data(
+    n,
+    p,
+    seed = 1,
+    family = "mgaussian",
+    beta = matrix(rep(c(
+      rep(1, 5), rep(0, p - 5)
+    ), 3),
+    ncol = 3)
+  ))
+  expect_visible(generate.data(
+    n,
+    p,
+    seed = 1,
+    family = "multinomial",
+    beta = matrix(rep(c(
+      rep(1, 5), rep(0, p - 5)
+    ), 3),
+    ncol = 3)
+  ))
 })
