@@ -2,7 +2,7 @@ library(abess)
 library(testthat)
 
 test_batch <- function(n, p, support_size, family, formula) {
-  dataset <- generate.data(n, p, support_size, 
+  dataset <- generate.data(n, p, support_size,
                            family = family, seed = 1)
   if (formula) {
     if (family == "mgaussian") {
@@ -10,57 +10,97 @@ test_batch <- function(n, p, support_size, family, formula) {
     } else if (family == "cox") {
       dat <- cbind.data.frame(dataset[["x"]], dataset[["y"]])
     } else {
-      dat <- cbind.data.frame(dataset[["x"]][, 1:30], "y" = dataset[["y"]], 
+      dat <- cbind.data.frame(dataset[["x"]][, 1:30],
+                              "y" = dataset[["y"]],
                               dataset[["x"]][, 31:p])
     }
   }
   if (family %in% c("gaussian", "mgaussian")) {
-    abess_fit <- abess(dataset[["x"]], dataset[["y"]], family = family, 
-                       tune.type = "gic", screening.num = n, support.size = 0:2)
+    abess_fit <- abess(
+      dataset[["x"]],
+      dataset[["y"]],
+      family = family,
+      tune.type = "gic",
+      screening.num = n,
+      support.size = 0:2
+    )
     if (formula) {
       if (family == "mgaussian") {
-        abess_fit <- abess(cbind(y1, y2, y3) ~ ., data = dat, 
-                           family = "mgaussian", tune.type = "gic", 
-                           screening.num = n, support.size = 0:2)
+        abess_fit <- abess(
+          cbind(y1, y2, y3) ~ .,
+          data = dat,
+          family = "mgaussian",
+          tune.type = "gic",
+          screening.num = n,
+          support.size = 0:2
+        )
       } else {
-        abess_fit <- abess(y ~ ., data = dat, 
-                           tune.type = "gic", 
-                           screening.num = n, 
-                           family = family, support.size = 0:2)
+        abess_fit <- abess(
+          y ~ .,
+          data = dat,
+          tune.type = "gic",
+          screening.num = n,
+          family = family,
+          support.size = 0:2
+        )
       }
     }
   } else {
     if (family == "poisson") {
-      abess_fit <- abess(dataset[["x"]], dataset[["y"]], family = family, 
-                         tune.type = "gic", screening.num = n, 
-                         max.newton.iter = 50, support.size = 0:2, newton.thresh = 1e-8)      
+      abess_fit <- abess(
+        dataset[["x"]],
+        dataset[["y"]],
+        family = family,
+        tune.type = "gic",
+        screening.num = n,
+        max.newton.iter = 50,
+        support.size = 0:2,
+        newton.thresh = 1e-8
+      )
     } else {
-      abess_fit <- abess(dataset[["x"]], dataset[["y"]], family = family, 
-                         tune.type = "gic", screening.num = n, 
-                         newton = "approx", support.size = 0:2)
+      abess_fit <- abess(
+        dataset[["x"]],
+        dataset[["y"]],
+        family = family,
+        tune.type = "gic",
+        screening.num = n,
+        newton = "approx",
+        support.size = 0:2
+      )
     }
-
-
+    
+    
     if (formula) {
       if (family == "cox") {
-        abess_fit <- abess(cbind(time, status) ~ ., data = dat, 
-                           tune.type = "gic", 
-                           screening.num = n, 
-                           family = family, 
-                           newton = "approx", support.size = 0:2)
+        abess_fit <- abess(
+          cbind(time, status) ~ .,
+          data = dat,
+          tune.type = "gic",
+          screening.num = n,
+          family = family,
+          newton = "approx",
+          support.size = 0:2
+        )
       } else if (family == "poisson") {
-        abess_fit <- abess(y ~ ., data = dat, 
-                           tune.type = "gic", 
-                           screening.num = n, 
-                           family = family, 
-                           support.size = 0:2, 
-                           max.newton.iter = 50)
+        abess_fit <- abess(
+          y ~ .,
+          data = dat,
+          tune.type = "gic",
+          screening.num = n,
+          family = family,
+          support.size = 0:2,
+          max.newton.iter = 50
+        )
       } else {
-        abess_fit <- abess(y ~ ., data = dat, 
-                           tune.type = "gic", 
-                           screening.num = n, 
-                           family = family, 
-                           newton = "approx", support.size = 0:2)
+        abess_fit <- abess(
+          y ~ .,
+          data = dat,
+          tune.type = "gic",
+          screening.num = n,
+          family = family,
+          newton = "approx",
+          support.size = 0:2
+        )
       }
     }
   }
@@ -79,8 +119,8 @@ test_batch <- function(n, p, support_size, family, formula) {
 }
 
 test_that("screening (gaussian) works", {
-  n <- 200
-  p <- 2000
+  n <- 100
+  p <- 1000
   support_size <- 3
   
   ## default interface
@@ -91,8 +131,8 @@ test_that("screening (gaussian) works", {
 })
 
 test_that("screening (binomial) works", {
-  n <- 200
-  p <- 2000
+  n <- 100
+  p <- 1000
   support_size <- 3
   
   ## default interface
@@ -103,8 +143,8 @@ test_that("screening (binomial) works", {
 })
 
 test_that("screening (cox) works", {
-  n <- 100
-  p <- 300
+  n <- 128
+  p <- 128
   support_size <- 3
   
   ## default interface
@@ -115,9 +155,9 @@ test_that("screening (cox) works", {
 })
 
 test_that("screening (poisson) works", {
-  n <- 200
-  p <- 2500
-  support_size <- 4
+  n <- 150
+  p <- 1000
+  support_size <- 3
   
   ## default interface
   test_batch(n, p, support_size, "poisson", FALSE)
@@ -127,8 +167,8 @@ test_that("screening (poisson) works", {
 })
 
 test_that("screening (mgaussian) works", {
-  n <- 200
-  p <- 2000
+  n <- 100
+  p <- 1000
   support_size <- 3
   
   ## default interface
@@ -139,8 +179,8 @@ test_that("screening (mgaussian) works", {
 })
 
 test_that("screening (multinomial) works", {
-  n <- 200
-  p <- 2000
+  n <- 100
+  p <- 1000
   support_size <- 3
   
   ## default interface
@@ -149,3 +189,4 @@ test_that("screening (multinomial) works", {
   ## formula interface
   test_batch(n, p, support_size, "multinomial", TRUE)
 })
+
